==> kdevelop_5.2.1.orig.tar.xz: kdevelop-5.2.1/plugins/custom-buildsystem/kcm_kdevcustombuildsystem.desktop.cmake <==
[Desktop Entry]
Icon=kdevelop
Type=Service
ServiceTypes=KCModule

X-KDE-ModuleType=Library
X-KDE-Library=kdevplatform/@KDEV_PLUGIN_VERSION@/kcm/kcm_kdevcustombuildsystem
X-KDE-ParentApp=kdevplatformproject
X-KDE-ParentComponents=KDevCustomBuildSystem
X-KDE-CfgDlgHierarchy=BUILDTOOL

Name=Custom BuildSystem
Name[bs]=Vlasititi sistem gradnje
Name[ca]=BuildSystem personalitzat
Name[ca@valencia]=BuildSystem personalitzat
Name[cs]=Vlastní systém pro sestavení
Name[da]=Tilpasset byggesystem
Name[de]=Eigenes Build-System
Name[el]=Προσαρμοσμένο σύστημα κατασκευής
Name[en_GB]=Custom Build System
Name[es]=Sistema de construcción personalizado
Name[et]=Kohandatud ehitamissüsteem
Name[fi]=Oma käännösjärjestelmä
Name[fr]=Système de compilation personnalisé
Name[gl]=Sistema de compilación personalizado
Name[hu]=Egyéni fordítórendszer
Name[it]=BuildSystem personalizzato
Name[kk]=Әдеттен тыс құрастыру жүйесі
Name[nb]=Egendefinert BuildSystem
Name[nl]=Eigen bouwsysteem
Name[pl]=Własny system budowania
Name[pt]=Sistema de Compilação Personalizado
Name[pt_BR]=Sistema de compilação personalizado
Name[ru]=Собственная система сборки
Name[sk]=Vlastný buildovací systém
Name[sl]=Sistem za izgradnjo po meri
Name[sv]=Eget byggsystem
Name[tr]=Özel Derleme Sistemi
Name[uk]=Нетипова система збирання
Name[x-test]=xxCustom BuildSystemxx
Name[zh_CN]=自定义构建系统
Name[zh_TW]=自訂編譯系統
Comment=Configure a projects custom build tool and includes/defines for the language support.
Comment[bs]=Konfiguriši vlastite alate za gradnju i uključivanja/definicije za jezičku podršku.
Comment[ca]=Configura una eina de construcció personalitzada de projectes i les inclusions/definicions per la implementació del llenguatge.
Comment[ca@valencia]=Configura una eina de construcció personalitzada de projectes i les inclusions/definicions per la implementació del llenguatge.
Comment[da]=Konfigurér et projekts tilpassede byggeværktøj og include-filer og definitioner for sprogunderstøttelse.
Comment[de]=Einrichtung eines Projekt-Build-Systems und „includes/defines“ für die Sprachen-Unterstützung
Comment[el]=Διαμορφώνει ένα εργαλείο προσαρμοσμένης κατασκευής για έργα και τα includes/defines για τη γλωσσική υποστήριξη.
Comment[en_GB]=Configure a projects custom build tool and includes/defines for the language support.
Comment[es]=Configurar una herramienta de construcción personalizada de proyectos e includes y defines para el lenguaje.
Comment[et]=Projektide kohandatud ehitamistööriista ning keeletoetuseks vajalike päiste ja definitsioonide seadistamine.
Comment[fi]=Projektin oman käännöstyökalun asetukset sekä kielituen include/define-hakupolut.
Comment[fr]=Configure un outil de compilation personnalisé de projets ainsi que des inclusions / définitions pour la prise en charge des langages.
Comment[gl]=Configurar a ferramenta de construción personalizada dun proxecto e os «includes»/«defines» para o soporte lingüístico.
Comment[hu]=A projektek egyéni fordítóeszközének beállítása és tartalmazása/meghatározása a nyelvi támogatáshoz.
Comment[it]=Configura uno strumento di compilazione personalizzato per i progetti e le direttive include/define per il supporto del linguaggio.
Comment[kk]=Өзгеше құрастыру құралы мен тілдің кірме/анықтамаларын баптау.
Comment[nb]=Sett opp et prosjekts egendefinerte byggeverktøy og inkluderinger/definisjoner for språkstøtten.
Comment[nl]=Stel het eigen bouwhulpmiddel van een project in en voeg toe/definieer de ondersteuning van taal.
Comment[pl]=Ustaw narzędzie własnego systemu budowania i pliki dołączane/definiujące dla obsługi języka.
Comment[pt]=Configura uma ferramenta de compilação de projectos personalizada e as inclusões/definições do suporte para uma linguagem.
Comment[pt_BR]=Configura uma ferramenta de compilação de projetos personalizados e inclusões/definições para suporte de linguagens.
Comment[ru]=Настраивает собственное средство сборки проектов и включает/определяет поддержку языков.
Comment[sk]=Nastaviť vlastné buildovacie nástroje projektov a zahrnúť/definovať podporu jazyka.
Comment[sl]=Nastavi orodje za izgradnjo po meri in vključitve/določila za podporo jeziku.
Comment[sv]=Anpassa ett projekts egna byggsystem samt deklarationer och definitioner för språkstödet.
Comment[tr]=Bir projenin özel derleme aracını yapılandırır ve dil desteği için tanımları içerir.
Comment[uk]=Налаштування типового інструмента збирання проектів та включень або визначень щодо підтримки мов.
Comment[x-test]=xxConfigure a projects custom build tool and includes/defines for the language support.xx
Comment[zh_CN]=配置工程的自定义构建工具以及语言支持的包含/定义
Comment[zh_TW]=設定專案自訂編譯系統，並加入或定義語言的支援。

==> kdevelop-5.4.0.tar.xz: kdevelop-5.4.0/plugins/custom-buildsystem/kcm_kdevcustombuildsystem.desktop.cmake <==
[Desktop Entry]
Icon=kdevelop
Type=Service
ServiceTypes=KCModule

X-KDE-ModuleType=Library
X-KDE-Library=kdevplatform/@KDEV_PLUGIN_VERSION@/kcm/kcm_kdevcustombuildsystem
X-KDE-ParentApp=kdevplatformproject
X-KDE-ParentComponents=KDevCustomBuildSystem
X-KDE-CfgDlgHierarchy=BUILDTOOL

Name=Custom BuildSystem
Name[bs]=Vlasititi sistem gradnje
Name[ca]=BuildSystem personalitzat
Name[ca@valencia]=BuildSystem personalitzat
Name[cs]=Vlastní systém pro sestavení
Name[da]=Tilpasset byggesystem
Name[de]=Eigenes Build-System
Name[el]=Προσαρμοσμένο σύστημα κατασκευής
Name[en_GB]=Custom Build System
Name[es]=Sistema de construcción personalizado
Name[et]=Kohandatud ehitamissüsteem
Name[fi]=Oma käännösjärjestelmä
Name[fr]=Système de compilation personnalisé
Name[gl]=Sistema de compilación personalizado
Name[hu]=Egyéni fordítórendszer
Name[it]=BuildSystem personalizzato
Name[kk]=Әдеттен тыс құрастыру жүйесі
Name[nb]=Egendefinert BuildSystem
Name[nl]=Eigen bouwsysteem
Name[pl]=Własny system budowania
Name[pt]=Sistema de Compilação Personalizado
Name[pt_BR]=Sistema de compilação personalizado
Name[ru]=Собственная система сборки
Name[sk]=Vlastný buildovací systém
Name[sl]=Sistem za izgradnjo po meri
Name[sv]=Eget byggsystem
Name[tr]=Özel Derleme Sistemi
Name[uk]=Нетипова система збирання
Name[x-test]=xxCustom BuildSystemxx
Name[zh_CN]=自定义构建系统
Name[zh_TW]=自訂編譯系統
Comment=Configure a projects custom build tool and includes/defines for the language support.
Comment[bs]=Konfiguriši vlastite alate za gradnju i uključivanja/definicije za jezičku podršku.
Comment[ca]=Configura una eina de construcció personalitzada de projectes i les inclusions/definicions per la implementació del llenguatge.
Comment[ca@valencia]=Configura una eina de construcció personalitzada de projectes i les inclusions/definicions per la implementació del llenguatge.
Comment[da]=Konfigurér et projekts tilpassede byggeværktøj og include-filer og definitioner for sprogunderstøttelse.
Comment[de]=Einrichtung eines Projekt-Build-Systems und „includes/defines“ für die Sprachen-Unterstützung
Comment[el]=Διαμορφώνει ένα εργαλείο προσαρμοσμένης κατασκευής για έργα και τα includes/defines για τη γλωσσική υποστήριξη.
Comment[en_GB]=Configure a projects custom build tool and includes/defines for the language support.
Comment[es]=Configurar una herramienta de construcción personalizada de proyectos e includes y defines para el lenguaje.
Comment[et]=Projektide kohandatud ehitamistööriista ning keeletoetuseks vajalike päiste ja definitsioonide seadistamine.
Comment[fi]=Projektin oman käännöstyökalun asetukset sekä kielituen include/define-hakupolut.
Comment[fr]=Configure un outil de compilation personnalisé de projets ainsi que des inclusions / définitions pour la prise en charge des langages.
Comment[gl]=Configurar a ferramenta de construción personalizada dun proxecto e os «includes»/«defines» para o soporte lingüístico.
Comment[hu]=A projektek egyéni fordítóeszközének beállítása és tartalmazása/meghatározása a nyelvi támogatáshoz.
Comment[it]=Configura uno strumento di compilazione personalizzato per i progetti e le direttive include/define per il supporto del linguaggio.
Comment[kk]=Өзгеше құрастыру құралы мен тілдің кірме/анықтамаларын баптау.
Comment[nb]=Sett opp et prosjekts egendefinerte byggeverktøy og inkluderinger/definisjoner for språkstøtten.
Comment[nl]=Stel het eigen bouwhulpmiddel van een project in en voeg toe/definieer de ondersteuning van taal.
Comment[pl]=Ustaw narzędzie własnego systemu budowania i pliki dołączane/definiujące dla obsługi języka.
Comment[pt]=Configura uma ferramenta de compilação de projectos personalizada e as inclusões/definições do suporte para uma linguagem.
Comment[pt_BR]=Configura uma ferramenta de compilação de projetos personalizados e inclusões/definições para suporte de linguagens.
Comment[ru]=Настраивает собственное средство сборки проектов и включает/определяет поддержку языков.
Comment[sk]=Nastaviť vlastné buildovacie nástroje projektov a zahrnúť/definovať podporu jazyka.
Comment[sl]=Nastavi orodje za izgradnjo po meri in vključitve/določila za podporo jeziku.
Comment[sv]=Anpassa ett projekts egna byggsystem samt deklarationer och definitioner för språkstödet.
Comment[tr]=Bir projenin özel derleme aracını yapılandırır ve dil desteği için tanımları içerir.
Comment[uk]=Налаштування типового інструмента збирання проєктів та включень або визначень щодо підтримки мов.
Comment[x-test]=xxConfigure a projects custom build tool and includes/defines for the language support.xx
Comment[zh_CN]=配置工程的自定义构建工具以及语言支持的包含/定义
Comment[zh_TW]=設定專案自訂編譯系統，並加入或定義語言的支援。
